@@ -2,6 +2,9 @@
 #'
 #' @details See \url{https://radiant-rstats.github.io/docs} for documentation and tutorials
 #'
+#' @param state Path to state file to load
+#' @param ... additional arguments to pass to shiny::runApp (e.g, port = 8080)
+#'
 #' @importFrom radiant.data launch
 #'
 #' @examples
@@ -9,12 +12,15 @@
 #' radiant.design()
 #' }
 #' @export
-radiant.design <- function() radiant.data::launch(package = "radiant.design", run = "browser")
+radiant.design <- function(state, ...) radiant.data::launch(package = "radiant.design", run = "browser", state, ...)
 
 #' Launch radiant.design in an Rstudio window
 #'
 #' @details See \url{https://radiant-rstats.github.io/docs} for documentation and tutorials
 #'
+#' @param state Path to state file to load
+#' @param ... additional arguments to pass to shiny::runApp (e.g, port = 8080)
+#'
 #' @importFrom radiant.data launch
 #'
 #' @examples
@@ -22,12 +28,15 @@ radiant.design <- function() radiant.data::launch(package = "radiant.design", ru
 #' radiant.design_window()
 #' }
 #' @export
-radiant.design_window <- function() radiant.data::launch(package = "radiant.design", run = "window")
+radiant.design_window <- function(state, ...) radiant.data::launch(package = "radiant.design", run = "window", state, ...)
 
 #' Launch radiant.design in the Rstudio viewer
 #'
 #' @details See \url{https://radiant-rstats.github.io/docs} for documentation and tutorials
 #'
+#' @param state Path to state file to load
+#' @param ... additional arguments to pass to shiny::runApp (e.g, port = 8080)
+#'
 #' @importFrom radiant.data launch
 #'
 #' @examples
@@ -35,4 +44,4 @@ radiant.design_window <- function() radiant.data::launch(package = "radiant.desi
 #' radiant.design_viewer()
 #' }
 #' @export
-radiant.design_viewer <- function() radiant.data::launch(package = "radiant.design", run = "viewer")
+radiant.design_viewer <- function(state, ...) radiant.data::launch(package = "radiant.design", run = "viewer", state, ...)
