@@ -54,7 +54,7 @@ sampling <- function(
 summary.sampling <- function(object, prn = FALSE, dec = 3, ...) {
   cat("Sampling (simple random)\n")
   cat("Data       :", object$df_name, "\n")
-  if (object$data_filter %>% gsub("\\s", "", .) != "") {
+  if (!is_empty(object$data_filter)) {
     cat("Filter     :", gsub("\\n", "", object$data_filter), "\n")
   }
   cat("ID variable:", object$var, "\n")
